% @Author: Angel Alonso
% Company: Coriant GmbH Muenchen
% Univesity: Politecnico di Torino & Universidad Politecnica de Madrid 

% This returns NLI PSD at f.
% It uses Hyperbolic Coordinates
% Bibliography: Pierluigi Poggiolini : "Th GN Model of Non-Linear Propagation
%                                       in Uncompensated Coherent Optical Systems"

% ============================================================
%             				INPUT
% ============================================================
% 
% fiberParams: Type: Struct. It contains fiber parameters (alpha,beta2 and gamma)
% signal: Type: Struct. It contains signal parameters (power,roll-off,Bw and Rs)
% sys: Type: Struct. It contains system parameters (number of channels, 
% span length, number of spans, bw, EDFA Gain, Figure Noise)
% f: Type: Double. Frequency under analysis. Baseband. f=0 central channel [THz]
% gtx: Type: Double Array. WDM Signal Spectrum [W/Hz]
%
% ============================================================
%             				OUTPUT
% ============================================================
%
% GNLI0: Type: Double. NLI PSD at f [W/Hz]


function GNLI0=GNLI_f_hyp(fiberParams,signal,sys,f,gtx)
	nSamples = floor(sys.Bw*23000/2); 
	freq = linspace(-sys.Bw/2,sys.Bw/2,nSamples);
	% gtx = GTX(signal,sys,freq);
	% Parameters
	Leff = (1-exp(-2*fiberParams.alpha*sys.Ls))/(2*fiberParams.alpha); % Effective span length
	resolv1=16; % After evaluating the integral convergence. Our resolution along v1 is 16 samples/GHz
	nSamplesv1=floor(resolv1*sys.Bw*1000);
	% Let's compute GNRF at f=0
	v1=linspace(0,sys.Bw,2*nSamplesv1);
	%pace=v1(2);
	p0num=1-exp(-2*fiberParams.alpha*sys.Ls)*exp(1i*4*pi^2*fiberParams.GVD*sys.Ls*v1.^2);
	p0dem=2*fiberParams.alpha-1i*4*pi^2*fiberParams.GVD*v1.^2;
	p0=abs(p0num./p0dem).^2; %FWM efficiency for f=0
	p0=p0/(Leff^2);
	p0=10*log10(p0);
	th=-30; % Threshold to speed up the numerical integration. The bigger, the faster.
	ind=find(p0>=th);
	p0=p0(ind);
	p0=10.^(p0/10);
	v1=v1(ind);
	x0num=sin(2*sys.Ns*pi^2*v1.^2*fiberParams.GVD*sys.Ls).^2;
	x0dem=sin(2*pi^2*v1.^2*fiberParams.GVD*sys.Ls).^2;
	x0=x0num./x0dem;
	x0(1)=sys.Ns^2;

	A=p0.*x0.*abs(2*v1);
	A=A/max(A);
	A=10*log10(A);
	ind2 = find(A<-20);
	Gnli0=zeros(1,length(v1));
	fprintf('Processed   0%%')
	for jj =1:length(v1)
    	if(jj==1)
       		v2upLim=log(sys.Bw/(0.0001));
    	else
       		v2upLim = log(sys.Bw/(v1(jj)));
    	end
    	if ismember(jj,ind2)
    
    	else
        	v2 = linspace(0,v2upLim,nSamplesv1);
        	freq01 = v1(jj).*exp(v2)+f;
        	freq02 = v1(jj).*exp(-v2)+f;
        	freq03 = 2*v1(jj).*cosh(v2)+f;
        	freq04 = -v1(jj).*exp(-v2)+f;
        	freq05 = 2*v1(jj)*sinh(v2)+f;
        	freq06 = -v1(jj).*exp(v2)+f;
        	freq07 = -2*v1(jj).*sinh(v2)+f;
        	freq08 = -2*v1(jj).*cosh(v2)+f;
        	g01 = interp1(freq,gtx,freq01,'cubic');
        	g02 = interp1(freq,gtx,freq02,'cubic');
        	g03 = interp1(freq,gtx,freq03,'cubic');
        	g04 = interp1(freq,gtx,freq04,'cubic');
        	g05 = interp1(freq,gtx,freq05,'cubic');
        	g06 = interp1(freq,gtx,freq06,'cubic');
        	g07 = interp1(freq,gtx,freq07,'cubic');
        	g08 = interp1(freq,gtx,freq08,'cubic');
        	I0=g01.*g02.*g03+g01.*g04.*g05+g06.*g02.*g07+g06.*g04.*g08;
        	Gnli0(jj)=trapz(v2,I0); %Inner integral. Integration domain over v2
    	end
    	if mod(jj, 100) == 0
        	fprintf('\b\b\b%g%%', round(jj*100/length(v1)))
    	end    
	end
	II=p0.*x0.*Gnli0.*abs(2*v1);
	GNLI0=trapz(v1,II); %Outer intergral. Integration domain over v1
	GNLI0=(32/27)*(fiberParams.gamma^2)*(Leff^2)*GNLI0*1e-12; % PSD in W/Hz

	end    