% @Author: Angel Alonso
% Company: Coriant

% This function returns the main parameters of a fiber
%
% INPUT
% fiberType : It's a string to select the type of fiber
%
% OUTPUT
% fiberParams : It's a struct that has some fiber parameters inside
%   alpha     : Attenuation Coefficient defined as alpha_dB/8.686 [1/km]
%   D         : Dispersion Coefficient [ps/km.nm]
%   gamma     : Non-Linearity Coefficient [1/W.km]

function fiberParams = fiberParam(fiberType)
switch fiberType
    case 'CORIANT'
        GVD = -23.0174; % Propagation Constant [ps^2/km]
        alpha = 0.1616/(20*log10(exp(1))); % Fiber Loss [dB/km]
        alpha =0.0191;
        gamma = 1.0088; % [1/W.km]
    case 'ORANGE'
        D = 16.7; % Dispersion Parameter [ps/nm/km]
        c = 299792458; % Speed Light in vacuum
        lo = 1545.3; % Central Wavelength [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.2/(20*log10(exp(1))); % Fiber Loss [dB/km]
        gamma=1.27; % Nonlinear Coefficient [1/w/km]       
    case 'TIM'
        D = 16.67;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.316/(20*log10(exp(1)));
        gamma=1.25;
    case 'PSCF'
        D=20.1;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.18/(20*log10(exp(1)));
        gamma=0.9;
    case 'SMF'
        D=16.7;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.22/(20*log10(exp(1)));
        gamma=1.3;
    case 'NZDSF'
        D=3.8;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.22/(20*log10(exp(1)));
        gamma=1.5;
    case 'SSMF'
        D=16.84;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.19/(20*log10(exp(1)));
        gamma=1.26;
    case 'NZDSF2'
        D=2.58;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.2/(20*log10(exp(1)));
        gamma=2;
    case 'PSCF80'
        D=16.36;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.164/(20*log10(exp(1)));
        gamma=1.04;
    case 'PSCF110'
        D=20.50;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.161/(20*log10(exp(1)));
        gamma=0.81;
    case 'PSCF130'
        D=20.92;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.162/(20*log10(exp(1)));
        gamma=0.68;
     case 'PSCF150'
        D=20.69;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.161/(20*log10(exp(1)));
        gamma=0.59; 
    case 'DCF'
        D=-166.47;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.457/(20*log10(exp(1)));
        gamma=6.03;
    case 'PSCF152'
        D=21.6;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.18/(20*log10(exp(1)));
        gamma=0.59; 
    case 'SMF_Mattia'
        D=16.7;
        c = 299792458; % Speed Light in vacuum
        lo = 1550; % Central Wavelegnth [nm]
        GVD = -lo^2*D/(2*pi*c*10^(-3)); % Propagation Constant [ps^2/km]
        alpha=0.2/(20*log10(exp(1)));
        gamma=1.27; 
end
fiberParams=struct('alpha',alpha,'GVD',GVD,'gamma',gamma);
end

        